# Generated by Django 5.1.2 on 2024-10-25 14:07

import logging

import django.db.models.deletion
from django.db import migrations, models
from django.utils.text import slugify

from zgw_consumers.constants import APITypes, AuthTypes

logger = logging.getLogger(__name__)


def migrate_authorization_config_to_service(apps, _) -> None:
    AuthorizationsConfig = apps.get_model("authorizations", "AuthorizationsConfig")
    Service = apps.get_model("zgw_consumers", "Service")

    service_label = "Authorization API service"

    config, _ = AuthorizationsConfig.objects.get_or_create()
    service, created = Service.objects.get_or_create(
        api_root=config.api_root,
        defaults=dict(
            label="Authorization API service",
            slug=slugify(service_label),
            api_type=APITypes.ac,
            auth_type=AuthTypes.zgw,
        ),
    )
    config.authorizations_api_service = service
    config.save()

    if created:
        logger.info(f"Created new Service for {config.api_root}")
    else:
        logger.info(f"Existing service found for {config.api_root}")


def migrate_authorization_config_to_config(apps, _) -> None:
    AuthorizationsConfig = apps.get_model("authorizations", "AuthorizationsConfig")

    config, _ = AuthorizationsConfig.objects.get_or_create()
    if config.authorizations_api_service:
        config.api_root = config.authorizations_api_service.api_root
    config.save()


class Migration(migrations.Migration):

    dependencies = [
        ("authorizations", "0015_auto_20220318_1608"),
        ("zgw_consumers", "0022_set_default_service_slug"),
    ]

    operations = [
        migrations.AddField(
            model_name="authorizationsconfig",
            name="authorizations_api_service",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"api_type": "ac", "auth_type": "zgw"},
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="zgw_consumers.service",
                verbose_name="autorisations api service",
            ),
        ),
        migrations.RunPython(
            migrate_authorization_config_to_service,
            reverse_code=migrate_authorization_config_to_config,
        ),
        migrations.RemoveField(
            model_name="authorizationsconfig",
            name="api_root",
        ),
    ]
